@@ -217,17 +217,19 @@ class RHMailman(Mailman):
             match_dicts = (match.groupdict() for match in matches)
 
             for match_dict in match_dicts:
-                match_dict['cache_url'] = self.url(match_dict['url'])
-                match_dict['cache_file'] = match_dict['url'].replace('/', '-')
-                match_dict['identifier'] = "%s-%s" % ( match_dict['year'], match_dict['month'])
-                match_dict['stream'] = self
-                match_dict['month'] = dup.parse('%s %s' % (match_dict['month'], match_dict['year']))
+                try:
+                    match_dict['cache_url'] = self.url(match_dict['url'])
+                    match_dict['cache_file'] = match_dict['url'].replace('/', '-')
+                    match_dict['identifier'] = "%s-%s" % ( match_dict['year'], match_dict['month'])
+                    match_dict['stream'] = self
+                    match_dict['month'] = dup.parse('%s %s' % (match_dict['month'], match_dict['year']))
 
-                resp = conn.urlread(up.urlsplit(match_dict['cache_url']).path)
-                match_dict['size'] = len(resp)
-                yield match_dict
-        except KeyError, e:
-            print 'error fetching attribute %s' % e.message
+                    resp = conn.urlread(up.urlsplit(match_dict['cache_url']).path)
+                    match_dict['size'] = len(resp)
+                    yield match_dict
+                except KeyError, e:
+                    print 'error fetching attribute %s' % e.message
+                    continue
         except Exception, e:
             print 'fail doing something big, not sure what\'s going on'
             traceback.print_exc()
@@ -265,16 +267,18 @@ class MBoxMailman(Mailman):
             matches = self.regex.finditer(html)
             match_dicts = (match.groupdict() for match in matches)
             for match_dict in match_dicts:
-                match_dict['cache_url'] = self.url(match_dict['mbox'])
-                match_dict['cache_file'] = match_dict['mbox']
-                match_dict['identifier'] = match_dict['mbox']
-                match_dict['stream'] = self
-                match_dict['month'] = dup.parse('%s %s' % (match_dict['month'], match_dict['year']))
-                if type(match_dict['size']) is str:
-                    match_dict['size'] = int(match_dict['size'])
-                yield match_dict
-        except KeyError, e:
-            print 'error fetching attribute %s' % e.message
+                try:
+                    match_dict['cache_url'] = self.url(match_dict['mbox'])
+                    match_dict['cache_file'] = match_dict['mbox']
+                    match_dict['identifier'] = match_dict['mbox']
+                    match_dict['stream'] = self
+                    match_dict['month'] = dup.parse('%s %s' % (match_dict['month'], match_dict['year']))
+                    if type(match_dict['size']) is str:
+                        match_dict['size'] = int(match_dict['size'])
+                    yield match_dict
+                except KeyError, e:
+                    print 'error fetching attribute %s' % e.message
+                    continue
         except Exception, e:
             print 'fail doing something big, not sure what\'s going on'
             traceback.print_exc()
@@ -379,23 +383,25 @@ class MBoxSource(Source):
 
             mbox = self.mbox
             for email in iter_in_transaction(session, mbox):
-                email = dict(email.items())
-                
-                email['message_id'] = email['Message-ID']
-                email['sender'] = email['From']
-                email['sender_domain'] = self.fact.domain_from_sender(email['sender'])
-                email['source'] = self
-                # sometimes these fields are blank, which is kinda ok, because it's a garbage message
-                # but dateutil can't handle None, so we have to use this hack
                 try:
-                    email['date'] = dup.parse(email['Date'] or str(datetime.datetime.min)).replace(day=1)
-                except ValueError:
-                    print "TODO: Fix bad date parsing!"
-                    email['date'] = datetime.datetime.min
-                email['subject'] = email['Subject']
-                self.fact.create_or_update(self.core, **email)
-        except KeyError, e:
-            print 'error fetching attribute %s' % e.message
+                    email = dict(email.items())
+                
+                    email['message_id'] = email['Message-ID']
+                    email['sender'] = email['From']
+                    email['sender_domain'] = self.fact.domain_from_sender(email['sender'])
+                    email['source'] = self
+                    # sometimes these fields are blank, which is kinda ok, because it's a garbage message
+                    # but dateutil can't handle None, so we have to use this hack
+                    try:
+                        email['date'] = dup.parse(email['Date'] or str(datetime.datetime.min)).replace(day=1)
+                    except ValueError:
+                        print "TODO: Fix bad date parsing!"
+                        email['date'] = datetime.datetime.min
+                    email['subject'] = email['Subject']
+                    self.fact.create_or_update(self.core, **email)
+                except KeyError, e:
+                    print 'error fetching attribute %s' % e.message
+                    continue
         except Exception, e:
             print 'fail doing something big, not sure what\'s going on'
             traceback.print_exc()
@@ -452,36 +458,38 @@ class RHMailmanSource(Source):
             matches = self.regex.finditer(month_page)
             emails = (match.groupdict() for match in matches)
             for email in emails:
-                url = self.stream.archive + self.identifier + '/' + email['message']
-                loc = join(self.stream.cache, self.identifier, email['message'])
+                try:
+                    url = self.stream.archive + self.identifier + '/' + email['message']
+                    loc = join(self.stream.cache, self.identifier, email['message'])
 
-                url_split = up.urlsplit(url)
-                url_path = url_split.path
-                print url_path
-                email_data = conn.urlread(url_path)
-                print len(email_data)
-                with file(loc, 'w') as f:
-                    f.write(email_data)
+                    url_split = up.urlsplit(url)
+                    url_path = url_split.path
+                    print url_path
+                    email_data = conn.urlread(url_path)
+                    print len(email_data)
+                    with file(loc, 'w') as f:
+                        f.write(email_data)
 
 #             url_loc = urlretrieve(url, loc)
 #             email_data = htmlentitydecoder(codecs.open(loc, encoding='utf_8').read())
 
-                try:
-                    email['sender'] = self.regex_from.search(email_data).group('from')
-                except AttributeError:
-                    email['sender'] = 'nobody@example.com'
-                email['date'] = self.regex_date.search(email_data).group('date')
-                email['message_id'] = self.regex_message_id.search(email_data).group('message_id')
-                email['subject'] = self.regex_subject.search(email_data).group('subject')
-                email['source'] = self
-                try:
-                    email['date'] = dup.parse(email['date'])
-                except ValueError:
-                    print "TODO: Fix bad date parsing!"
-                    email['date'] = datetime.datetime.min
-                self.fact.create_or_update(self.core, **email)
-        except KeyError, e:
-            print 'error fetching attribute %s' % e.message
+                    try:
+                        email['sender'] = self.regex_from.search(email_data).group('from')
+                    except AttributeError:
+                        email['sender'] = 'nobody@example.com'
+                    email['date'] = self.regex_date.search(email_data).group('date')
+                    email['message_id'] = self.regex_message_id.search(email_data).group('message_id')
+                    email['subject'] = self.regex_subject.search(email_data).group('subject')
+                    email['source'] = self
+                    try:
+                        email['date'] = dup.parse(email['date'])
+                    except ValueError:
+                        print "TODO: Fix bad date parsing!"
+                        email['date'] = datetime.datetime.min
+                    self.fact.create_or_update(self.core, **email)
+                except KeyError, e:
+                    print 'error fetching attribute %s' % e.message
+                    continue
         except Exception, e:
             print 'fail doing something big, not sure what\'s going on'
             traceback.print_exc()
